@@ -30,7 +30,7 @@ class InstalledVersions
     'aliases' => 
     array (
     ),
-    'reference' => 'c44299430013bae161dceb0ae71a20a8d44b8efd',
+    'reference' => 'a5e3e8ca158a108608a3b700d53c4be67c7a8ebd',
     'name' => '__root__',
   ),
   'versions' => 
@@ -42,7 +42,7 @@ class InstalledVersions
       'aliases' => 
       array (
       ),
-      'reference' => 'c44299430013bae161dceb0ae71a20a8d44b8efd',
+      'reference' => 'a5e3e8ca158a108608a3b700d53c4be67c7a8ebd',
     ),
     'beberlei/assert' => 
     array (
@@ -73,12 +73,21 @@ class InstalledVersions
     ),
     'doctrine/inflector' => 
     array (
-      'pretty_version' => '2.0.6',
-      'version' => '2.0.6.0',
+      'pretty_version' => '2.0.8',
+      'version' => '2.0.8.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'd9d313a36c872fd6ee06d9a6cbcf713eaa40f024',
+      'reference' => 'f9301a5b2fb1216b2b08f02ba04dc45423db6bff',
+    ),
+    'duosecurity/duo_universal_php' => 
+    array (
+      'pretty_version' => '1.0.2',
+      'version' => '1.0.2.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => '8734a47480d2d2f0539e8ee782675e052025d026',
     ),
     'facile-it/php-jose-verifier' => 
     array (
@@ -107,14 +116,23 @@ class InstalledVersions
       ),
       'reference' => '42060ed45344789fb9f21f9f1864fc47b9e3507b',
     ),
-    'guzzlehttp/psr7' => 
+    'firebase/php-jwt' => 
     array (
-      'pretty_version' => '1.9.0',
-      'version' => '1.9.0.0',
+      'pretty_version' => 'v6.8.1',
+      'version' => '6.8.1.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'e98e3e6d4f86621a9b75f623996e6bbdeb4b9318',
+      'reference' => '5dbc8959427416b8ee09a100d7a8588c00fb2e26',
+    ),
+    'guzzlehttp/psr7' => 
+    array (
+      'pretty_version' => '1.9.1',
+      'version' => '1.9.1.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => 'e4490cabc77465aaee90b20cfc9a770f8c04be6b',
     ),
     'http-interop/http-factory-guzzle' => 
     array (
@@ -199,12 +217,12 @@ class InstalledVersions
     ),
     'nesbot/carbon' => 
     array (
-      'pretty_version' => '2.66.0',
-      'version' => '2.66.0.0',
+      'pretty_version' => '2.69.0',
+      'version' => '2.69.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '496712849902241f04902033b0441b269effe001',
+      'reference' => '4308217830e4ca445583a37d1bf4aff4153fa81c',
     ),
     'paragonie/constant_time_encoding' => 
     array (
@@ -240,30 +258,46 @@ class InstalledVersions
     ),
     'php-http/discovery' => 
     array (
-      'pretty_version' => '1.15.2',
-      'version' => '1.15.2.0',
+      'pretty_version' => '1.19.1',
+      'version' => '1.19.1.0',
       'aliases' => 
       array (
       ),
-      'reference' => '5cc428320191ac1d0b6520034c2dc0698628ced5',
+      'reference' => '57f3de01d32085fea20865f9b16fb0e69347c39e',
     ),
     'phpmailer/phpmailer' => 
     array (
-      'pretty_version' => 'v6.8.0',
-      'version' => '6.8.0.0',
+      'pretty_version' => 'v6.8.1',
+      'version' => '6.8.1.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'df16b615e371d81fb79e506277faea67a1be18f1',
+      'reference' => 'e88da8d679acc3824ff231fdc553565b802ac016',
     ),
     'phpseclib/phpseclib' => 
     array (
-      'pretty_version' => '3.0.19',
-      'version' => '3.0.19.0',
+      'pretty_version' => '3.0.21',
+      'version' => '3.0.21.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'cc181005cf548bfd8a4896383bb825d859259f95',
+      'reference' => '4580645d3fc05c189024eb3b834c6c1e4f0f30a1',
+    ),
+    'psr/clock' => 
+    array (
+      'pretty_version' => '1.0.0',
+      'version' => '1.0.0.0',
+      'aliases' => 
+      array (
+      ),
+      'reference' => 'e41a24703d4560fd0acb709162f73b8adfc3aa0d',
+    ),
+    'psr/clock-implementation' => 
+    array (
+      'provided' => 
+      array (
+        0 => '1.0',
+      ),
     ),
     'psr/container' => 
     array (
@@ -276,12 +310,12 @@ class InstalledVersions
     ),
     'psr/http-client' => 
     array (
-      'pretty_version' => '1.0.1',
-      'version' => '1.0.1.0',
+      'pretty_version' => '1.0.2',
+      'version' => '1.0.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => '2dfb5f6c5eff0e91e20e913f8c5452ed95b86621',
+      'reference' => '0955afe48220520692d2d09f7ab7e0f93ffd6a31',
     ),
     'psr/http-client-implementation' => 
     array (
@@ -293,29 +327,29 @@ class InstalledVersions
     ),
     'psr/http-factory' => 
     array (
-      'pretty_version' => '1.0.1',
-      'version' => '1.0.1.0',
+      'pretty_version' => '1.0.2',
+      'version' => '1.0.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => '12ac7fcd07e5b077433f5f2bee95b3a771bf61be',
+      'reference' => 'e616d01114759c4c489f93b099585439f795fe35',
     ),
     'psr/http-factory-implementation' => 
     array (
       'provided' => 
       array (
-        0 => '*',
-        1 => '^1.0',
+        0 => '^1.0',
+        1 => '*',
       ),
     ),
     'psr/http-message' => 
     array (
-      'pretty_version' => '1.0.1',
-      'version' => '1.0.1.0',
+      'pretty_version' => '1.1',
+      'version' => '1.1.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'f6561bf28d520154e4b0ec72be95418abe6d9363',
+      'reference' => 'cb6ce4845ce34a8ad9e68117c10ee90a29919eba',
     ),
     'psr/http-message-implementation' => 
     array (
@@ -327,21 +361,21 @@ class InstalledVersions
     ),
     'psr/http-server-handler' => 
     array (
-      'pretty_version' => '1.0.1',
-      'version' => '1.0.1.0',
+      'pretty_version' => '1.0.2',
+      'version' => '1.0.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'aff2f80e33b7f026ec96bb42f63242dc50ffcae7',
+      'reference' => '84c4fb66179be4caaf8e97bd239203245302e7d4',
     ),
     'psr/http-server-middleware' => 
     array (
-      'pretty_version' => '1.0.1',
-      'version' => '1.0.1.0',
+      'pretty_version' => '1.0.2',
+      'version' => '1.0.2.0',
       'aliases' => 
       array (
       ),
-      'reference' => '2296f45510945530b9dceb8bcedb5cb84d40c5f5',
+      'reference' => 'c1481f747daaa6a0782775cd6a8c26a1bf4a3829',
     ),
     'psr/log' => 
     array (
@@ -431,12 +465,12 @@ class InstalledVersions
     ),
     'symfony/http-client' => 
     array (
-      'pretty_version' => 'v5.4.21',
-      'version' => '5.4.21.0',
+      'pretty_version' => 'v5.4.26',
+      'version' => '5.4.26.0',
       'aliases' => 
       array (
       ),
-      'reference' => '6b88914a7f1bf144df15904f60a19be78a67a3b2',
+      'reference' => '19d48ef7f38e5057ed1789a503cd3eccef039bce',
     ),
     'symfony/http-client-contracts' => 
     array (
@@ -465,93 +499,93 @@ class InstalledVersions
     ),
     'symfony/mime' => 
     array (
-      'pretty_version' => 'v5.4.21',
-      'version' => '5.4.21.0',
+      'pretty_version' => 'v5.4.26',
+      'version' => '5.4.26.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'ef57d9fb9cdd5e6b2ffc567d109865d10b6920cd',
+      'reference' => '2ea06dfeee20000a319d8407cea1d47533d5a9d2',
     ),
     'symfony/polyfill-ctype' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '5bbc823adecdae860bb64756d639ecfec17b050a',
+      'reference' => 'ea208ce43cbb04af6867b4fdddb1bdbf84cc28cb',
     ),
     'symfony/polyfill-intl-idn' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '639084e360537a19f9ee352433b84ce831f3d2da',
+      'reference' => 'ecaafce9f77234a6a449d29e49267ba10499116d',
     ),
     'symfony/polyfill-intl-normalizer' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '19bd1e4fcd5b91116f14d8533c57831ed00571b6',
+      'reference' => '8c4ad05dd0120b6a53c1ca374dca2ad0a1c4ed92',
     ),
     'symfony/polyfill-mbstring' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '8ad114f6b39e2c98a8b0e3bd907732c207c2b534',
+      'reference' => '42292d99c55abe617799667f454222c54c60e229',
     ),
     'symfony/polyfill-php72' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '869329b1e9894268a8a61dabb69153029b7a8c97',
+      'reference' => '70f4aebd92afca2f865444d30a4d2151c13c3179',
     ),
     'symfony/polyfill-php73' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '9e8ecb5f92152187c4799efd3c96b78ccab18ff9',
+      'reference' => 'fe2f306d1d9d346a7fee353d0d5012e401e984b5',
     ),
     'symfony/polyfill-php80' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936',
+      'reference' => '6caa57379c4aec19c0a12a38b59b26487dcfe4b5',
     ),
     'symfony/polyfill-php81' => 
     array (
-      'pretty_version' => 'v1.27.0',
-      'version' => '1.27.0.0',
+      'pretty_version' => 'v1.28.0',
+      'version' => '1.28.0.0',
       'aliases' => 
       array (
       ),
-      'reference' => '707403074c8ea6e2edaf8794b0157a0bfa52157a',
+      'reference' => '7581cd600fa9fd681b797d00b02f068e2f13263b',
     ),
     'symfony/process' => 
     array (
-      'pretty_version' => 'v5.4.21',
-      'version' => '5.4.21.0',
+      'pretty_version' => 'v5.4.28',
+      'version' => '5.4.28.0',
       'aliases' => 
       array (
       ),
-      'reference' => 'd4ce417ebcb0b7d090b4c178ed6d3accc518e8bd',
+      'reference' => '45261e1fccad1b5447a8d7a8e67aa7b4a9798b7b',
     ),
     'symfony/psr-http-message-bridge' => 
     array (
@@ -573,12 +607,12 @@ class InstalledVersions
     ),
     'symfony/translation' => 
     array (
-      'pretty_version' => 'v5.4.21',
-      'version' => '5.4.21.0',
+      'pretty_version' => 'v5.4.24',
+      'version' => '5.4.24.0',
       'aliases' => 
       array (
       ),
-      'reference' => '6996affeea65705086939894b77110e9a7f80874',
+      'reference' => 'de237e59c5833422342be67402d487fbf50334ff',
     ),
     'symfony/translation-contracts' => 
     array (
