@@ -5,7 +5,7 @@ declare(strict_types=1);
 /*
  * The MIT License (MIT)
  *
- * Copyright (c) 2014-2019 Spomky-Labs
+ * Copyright (c) 2014-2021 Spomky-Labs
  *
  * This software may be modified and distributed under the terms
  * of the MIT license.  See the LICENSE file for details.
@@ -20,30 +20,29 @@ use Cose\Key\Key;
 
 abstract class ECDSA implements Signature
 {
-    public function __construct()
-    {
-        if (!method_exists($this, 'getSignaturePartLength')) {
-            @trigger_error('The method "getSignaturePartLength" is needed since 2.1 and will be mandatory in v3.0', E_USER_DEPRECATED);
-        }
-    }
-
     public function sign(string $data, Key $key): string
     {
         $key = $this->handleKey($key);
-        $result = openssl_sign($data, $signature, $key->asPEM(), $this->getHashAlgorithm());
-        Assertion::true($result, 'Unable to sign the data');
+        openssl_sign($data, $signature, $key->asPEM(), $this->getHashAlgorithm());
 
-        return $signature;
+        return ECSignature::fromAsn1($signature, $this->getSignaturePartLength());
     }
 
     public function verify(string $data, Key $key, string $signature): bool
     {
         $key = $this->handleKey($key);
         $publicKey = $key->toPublic();
+        $signature = ECSignature::toAsn1($signature, $this->getSignaturePartLength());
 
         return 1 === openssl_verify($data, $signature, $publicKey->asPEM(), $this->getHashAlgorithm());
     }
 
+    abstract protected function getCurve(): int;
+
+    abstract protected function getHashAlgorithm(): int;
+
+    abstract protected function getSignaturePartLength(): int;
+
     private function handleKey(Key $key): Ec2Key
     {
         $key = new Ec2Key($key->getData());
@@ -51,8 +50,4 @@ abstract class ECDSA implements Signature
 
         return $key;
     }
-
-    abstract protected function getCurve(): int;
-
-    abstract protected function getHashAlgorithm(): int;
 }
