@@ -36,7 +36,7 @@ use htmlResponsiveRow;
 include_once('../../lib/config.inc');
 
 // start session
-if (strtolower(session_module_name()) == 'files') {
+if (isFileBasedSession()) {
 	session_save_path("../../sess");
 }
 lam_start_session();
