@@ -1,6 +1,6 @@
 ﻿/*
-Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
+Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
+CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'en', {
 	copy: 'Copy',
@@ -11,5 +11,6 @@ CKEDITOR.plugins.setLang( 'clipboard', 'en', {
 	pasteNotification: 'Press %1 to paste. Your browser doesn‘t support pasting with the toolbar button or context menu option.',
 	pasteArea: 'Paste Area',
 	pasteMsg: 'Paste your content inside the area below and press OK.',
-	title: 'Paste'
+	fileFormatNotSupportedNotification: 'The ${formats} file format(s) are not supported.',
+	fileWithoutFormatNotSupportedNotification: 'The file format is not supported.'
 } );
