@@ -1,6 +1,6 @@
-/*
-Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
+﻿/*
+Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
+CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'pl', {
 	copy: 'Kopiuj',
@@ -10,5 +10,7 @@ CKEDITOR.plugins.setLang( 'clipboard', 'pl', {
 	paste: 'Wklej',
 	pasteNotification: 'Naciśnij %1 by wkleić tekst. Twoja przeglądarka nie pozwala na wklejanie za pomocą przycisku paska narzędzi lub opcji menu kontekstowego.',
 	pasteArea: 'Miejsce do wklejenia treści',
-	pasteMsg: 'Wklej treść do obszaru poniżej i naciśnij OK.'
+	pasteMsg: 'Wklej treść do obszaru poniżej i naciśnij OK.',
+	fileFormatNotSupportedNotification: 'The ${formats} file format(s) are not supported.', // MISSING
+	fileWithoutFormatNotSupportedNotification: 'The file format is not supported.' // MISSING
 } );
