@@ -1,6 +1,6 @@
-/*
-Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
+﻿/*
+Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
+CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
 */
 CKEDITOR.plugins.setLang( 'clipboard', 'ru', {
 	copy: 'Копировать',
@@ -10,5 +10,7 @@ CKEDITOR.plugins.setLang( 'clipboard', 'ru', {
 	paste: 'Вставить',
 	pasteNotification: 'Для вставки нажмите %1. Ваш браузер не поддерживает возможность вставки через панель инструментов или контекстное меню',
 	pasteArea: 'Область вставки',
-	pasteMsg: 'Вставьте контент в эту область и нажмите OK'
+	pasteMsg: 'Вставьте контент в эту область и нажмите OK',
+	fileFormatNotSupportedNotification: 'The ${formats} file format(s) are not supported.', // MISSING
+	fileWithoutFormatNotSupportedNotification: 'The file format is not supported.' // MISSING
 } );
