@@ -1,6 +1,6 @@
 ﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
+CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
 */
 CKEDITOR.plugins.setLang( 'colorbutton', 'cs', {
 	auto: 'Automaticky',
@@ -29,7 +29,7 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'cs', {
 		'0FF': 'Azurová',
 		'00F': 'Modrá',
 		EE82EE: 'Fialová',
-		A9A9A9: 'Kalně šedá',
+		A9A9A9: 'Tmavě šedá',
 		FFA07A: 'Světle lososová',
 		FFA500: 'Oranžová',
 		FFFF00: 'Žlutá',
@@ -45,7 +45,29 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'cs', {
 		F0FFFF: 'Azurová',
 		F0F8FF: 'Alenčina modrá',
 		E6E6FA: 'Levandulová',
-		FFF: 'Bílá'
+		FFF: 'Bílá',
+		'1ABC9C': 'Silná azurová',
+		'2ECC71': 'Emeraldová',
+		'3498DB': 'Jasně modrá',
+		'9B59B6': 'Ametystová',
+		'4E5F70': 'Šedomodrá',
+		'F1C40F': 'Sytá žlutá',
+		'16A085': 'Tmavě azurová',
+		'27AE60': 'Tmavě emeraldová',
+		'2980B9': 'Silná modrá',
+		'8E44AD': 'Tmavě fialová',
+		'2C3E50': 'Odsycená modrá',
+		'F39C12': 'Oranžová',
+		'E67E22': 'Mrkvová',
+		'E74C3C': 'Bledě červená',
+		'ECF0F1': 'Světle stříbrná',
+		'95A5A6': 'Světlě šedoazurová',
+		'DDD': 'Světle šedá',
+		'D35400': 'Dýňová',
+		'C0392B': 'Silná červená',
+		'BDC3C7': 'Stříbrná',
+		'7F8C8D': 'Šedoazurová',
+		'999': 'Tmavošedá'
 	},
 	more: 'Více barev...',
 	panelTitle: 'Barvy',
