@@ -1,6 +1,6 @@
 ﻿/*
-Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
-For licensing, see LICENSE.md or http://ckeditor.com/license
+Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
+CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
 */
 CKEDITOR.plugins.setLang( 'colorbutton', 'pl', {
 	auto: 'Automatycznie',
@@ -45,7 +45,29 @@ CKEDITOR.plugins.setLang( 'colorbutton', 'pl', {
 		F0FFFF: 'Jasnolazurowy',
 		F0F8FF: 'Jasnobłękitny',
 		E6E6FA: 'Lawendowy',
-		FFF: 'Biały'
+		FFF: 'Biały',
+		'1ABC9C': 'Cyjan',
+		'2ECC71': 'Szmaragdowy',
+		'3498DB': 'Jasnoniebieski',
+		'9B59B6': 'Ametystowy',
+		'4E5F70': 'Szaroniebieski',
+		'F1C40F': 'Żółty',
+		'16A085': 'Ciemny cyjan',
+		'27AE60': 'Ciemnoszmaragdowy',
+		'2980B9': 'Ciemnoniebieski',
+		'8E44AD': 'Ciemnofioletowy',
+		'2C3E50': 'Nienasycony niebieski',
+		'F39C12': 'Pomarańczowy',
+		'E67E22': 'Marchewkowy',
+		'E74C3C': 'Bladoczerwony',
+		'ECF0F1': 'Jasnosrebrny',
+		'95A5A6': 'Szarocyjanowy',
+		'DDD': 'Jasnoszary',
+		'D35400': 'Dyniowy',
+		'C0392B': 'Ciemnoczerwony',
+		'BDC3C7': 'Srebrny',
+		'7F8C8D': 'Szarawy cyjan',
+		'999': 'Ciemnoszary'
 	},
 	more: 'Więcej kolorów...',
 	panelTitle: 'Kolory',
