@@ -1,6 +1,6 @@
 ﻿/**
- * @license Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
- * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
+ * @license Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
+ * CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
  */
 
 /**
@@ -151,7 +151,8 @@ CKEDITOR.plugins.add( 'dialogui', {
 								'<label class="cke_dialog_ui_labeled_label' + requiredClass + '" ', ' id="' + _.labelId + '"',
 									( _.inputId ? ' for="' + _.inputId + '"' : '' ),
 									( elementDefinition.labelStyle ? ' style="' + elementDefinition.labelStyle + '"' : '' ) + '>',
-									elementDefinition.label,
+									// If label is required add asterisk. #3433)
+									( elementDefinition.required ? elementDefinition.label + '<span class="cke_dialog_ui_labeled_required" aria-hidden="true">*</span>' : elementDefinition.label ),
 								'</label>',
 								'<div class="cke_dialog_ui_labeled_content"',
 									( elementDefinition.controlStyle ? ' style="' + elementDefinition.controlStyle + '"' : '' ),
@@ -195,6 +196,8 @@ CKEDITOR.plugins.add( 'dialogui', {
 			 * A text input with a label. This UI element class represents both the
 			 * single-line text inputs and password inputs in dialog boxes.
 			 *
+			 * Since 4.11.0 it also represents the phone number input.
+			 *
 			 * @class CKEDITOR.ui.dialog.textInput
 			 * @extends CKEDITOR.ui.dialog.labeledElement
 			 * @constructor Creates a textInput class instance.
@@ -472,10 +475,15 @@ CKEDITOR.plugins.add( 'dialogui', {
 						if ( typeof inputDefinition.inputStyle != 'undefined' )
 							inputDefinition.style = inputDefinition.inputStyle;
 
-						// Make inputs of radio type focusable (https://dev.ckeditor.com/ticket/10866).
-						inputDefinition.keyboardFocusable = true;
+						var radioElement = new CKEDITOR.ui.dialog.uiElement( dialog, inputDefinition, inputHtml, 'input', null, inputAttributes );
 
-						children.push( new CKEDITOR.ui.dialog.uiElement( dialog, inputDefinition, inputHtml, 'input', null, inputAttributes ) );
+						// Calling the click method on the focus is responsible for updating the
+						// current focused index in the dialog (#439).
+						radioElement.on( 'focus', function() {
+							me.click();
+						} );
+
+						children.push( radioElement );
 
 						inputHtml.push( ' ' );
 
@@ -1080,7 +1088,7 @@ CKEDITOR.plugins.add( 'dialogui', {
 			/**
 			 * Sets the text direction marker and the `dir` attribute of the input element.
 			 *
-			 * @since 4.5
+			 * @since 4.5.0
 			 * @param {String} dir The text direction. Pass `null` to reset.
 			 */
 			setDirectionMarker: function( dir ) {
@@ -1101,7 +1109,7 @@ CKEDITOR.plugins.add( 'dialogui', {
 			/**
 			 * Gets the value of the text direction marker.
 			 *
-			 * @since 4.5
+			 * @since 4.5.0
 			 * @returns {String} `'ltr'`, `'rtl'` or `null` if the marker is not set.
 			 */
 			getDirectionMarker: function() {
@@ -1198,6 +1206,7 @@ CKEDITOR.plugins.add( 'dialogui', {
 			setValue: function( checked, noChangeEvent ) {
 				this.getInputElement().$.checked = checked;
 				!noChangeEvent && this.fire( 'change', { value: checked } );
+				return this;
 			},
 
 			/**
@@ -1245,6 +1254,42 @@ CKEDITOR.plugins.add( 'dialogui', {
 
 		/** @class CKEDITOR.ui.dialog.radio */
 		CKEDITOR.ui.dialog.radio.prototype = CKEDITOR.tools.extend( new CKEDITOR.ui.dialog.uiElement(), {
+			focus: function() {
+				var children = this._.children,
+					// Focus the first radio button in the group by default.
+					focusTarget = children[ 0 ],
+					dialogInternal = this._.dialog._,
+					currentFocusIndex = dialogInternal.currentFocusIndex,
+					isMovingBackwards = currentFocusIndex > this.focusIndex,
+					isStartingNewLoop = currentFocusIndex === dialogInternal.focusList.length - 1 && this.focusIndex === 0;
+
+				// If focus was changed by using SHIFT + TAB key and the previous radio group
+				// does not have any checked element, focus on the last one in the current radio group.
+				//
+				// When the dialog is shown and the first element is not focused,
+				// then, by default the 'currentFocusIndex' is set as
+				// the last element from the focus list, and it can be treated as moving focus backward,
+				// causing the focus to be incorrectly set to the last element of the radio
+				// group, instead of the first one (#439).
+				if ( isMovingBackwards && !isStartingNewLoop ) {
+					focusTarget = children[ children.length - 1 ];
+				}
+
+				// Set the dialog internal current focus index to the index of the current radio
+				// element from the focus list.
+				dialogInternal.currentFocusIndex = this.focusIndex;
+
+				for ( var i = 0; i < children.length; i++ ) {
+					var child = children[ i ];
+
+					if ( child.getInputElement().$.checked ) {
+						focusTarget = child;
+						break;
+					}
+				}
+
+				focusTarget.focus();
+			},
 			/**
 			 * Selects one of the radio buttons in this button group.
 			 *
@@ -1258,6 +1303,7 @@ CKEDITOR.plugins.add( 'dialogui', {
 				( i < children.length ) && ( item = children[ i ] ); i++ )
 					item.getElement().$.checked = ( item.getValue() == value );
 				!noChangeEvent && this.fire( 'change', { value: value } );
+				return this;
 			},
 
 			/**
@@ -1289,7 +1335,12 @@ CKEDITOR.plugins.add( 'dialogui', {
 				}
 				children[ 0 ].getElement().focus();
 			},
-
+			click: function() {
+				// Update currentFocusIndex after clicking on the given radio element. Otherwise, click
+				// will move the focus but the focus index will not be updated, causing moving the
+				// focus incorrectly based on the previous focus index while using Tab or Shift + Tab key (#439).
+				this._.dialog._.currentFocusIndex = this.focusIndex;
+			},
 			/**
 			 * Defines the `onChange` event for UI element definitions.
 			 *
@@ -1316,7 +1367,8 @@ CKEDITOR.plugins.add( 'dialogui', {
 					}
 					return null;
 				}
-			}
+			},
+			keyboardFocusable: true
 		}, commonPrototype, true );
 
 		/** @class CKEDITOR.ui.dialog.file */
@@ -1508,6 +1560,7 @@ CKEDITOR.plugins.add( 'dialogui', {
 
 		CKEDITOR.dialog.addUIElement( 'text', textBuilder );
 		CKEDITOR.dialog.addUIElement( 'password', textBuilder );
+		CKEDITOR.dialog.addUIElement( 'tel', textBuilder );
 		CKEDITOR.dialog.addUIElement( 'textarea', commonBuilder );
 		CKEDITOR.dialog.addUIElement( 'checkbox', commonBuilder );
 		CKEDITOR.dialog.addUIElement( 'radio', commonBuilder );
